---
name: Documentation
about: Create a documentation issue and assign
title: "[DOC]"
labels: 'documentation'
assignees: ''

---

**Describe the documentation issue**
A clear and concise description of what is wrong with our documentation.
